`xoutil.future`:mod: - Extend standard modules with "future" features
=====================================================================

.. automodule:: xoutil.future
   :members:


Contents
--------

.. toctree::
   :maxdepth: 1
   :glob:

   future/*
